@@ -36,13 +36,6 @@
  */
 class KioBluetoothPrivate;
 
-namespace BlueDevil {
-    class Device;
-    class Adapter;
-}
-
-using namespace BlueDevil;
-
 class KioBluetooth : public QObject, public KIO::SlaveBase
 {
   Q_OBJECT
@@ -62,7 +55,7 @@ public:
      * get function shall not do much other than setting a mimetype and returning some data that
      * could be useful for the mimetype handler.
      */
-    void get(const QUrl &url);
+    void get(const QUrl &url) Q_DECL_OVERRIDE;
 
     /**
      * List current directory. There are two types of current directories in this kio:
@@ -72,16 +65,16 @@ public:
      * 2. Remote device directory (something like bluetoth:/00_12_34_56_6d_34). This directory lists
      *    the services provided by the given remote device.
      */
-    void listDir(const QUrl &url);
+    void listDir(const QUrl &url) Q_DECL_OVERRIDE;
 
-    void stat(const QUrl &url);
+    void stat(const QUrl &url) Q_DECL_OVERRIDE;
 
     /**
      * As at the momento we don't handle more than one level url paths, @p setHost has not much
      * difference with @p listDir
      *
      */
-    void setHost(const QString &constHostname, quint16 port, const QString &user, const QString &pass);
+    void setHost(const QString &hostname, quint16 port, const QString &user, const QString &pass) Q_DECL_OVERRIDE;
 
     /**
      * Returns a list of supported service names corresponding to the given uuids list. If an uuid is
@@ -104,7 +97,6 @@ public Q_SLOTS:
     void listDevice(const DeviceInfo device);
 
 private:
-
     /**
      * This is set to true when @p setHost is called to list a given remote device, like for example
      * 00:2a:5E:8e:6e:f5. If listing the remote devices (bluetooth:/ uri), it's set back to false.
@@ -120,22 +112,9 @@ private:
     QString m_currentHostname;
 
     /**
-     * Represents the current host when @p hasCurrentHost is set to true. This is set in
-     * @p listRemoteDeviceServices function.
+     * Uppercase colon separated address (ex. 00:2A:5E:8E:6E:F5)
      */
-    Device *m_currentHost;
-
-    /**
-     * When @p hasCurrentHost to true, this list holds the list of service names provided by the
-     * current host (which is a remote device we can connect to using those services).
-     */
-    QList<Service> m_currentHostServices;
-
-    /**
-     * This is an array containing as key the uuid and as value the name of the service that the
-     * given uuid represents.
-     */
-    QMap<QString, QString> m_serviceNames;
+    QString m_currentHostAddress;
 
     /**
      * This is an array containing as key the uuid and as value the name of the service that the
